"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    intent_name: str,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    description: str = None,
    parent_intent_signature: str = None,
    sample_utterances: List = None,
    dialog_code_hook: Dict = None,
    fulfillment_code_hook: Dict = None,
    intent_confirmation_setting: Dict = None,
    intent_closing_setting: Dict = None,
    input_contexts: List = None,
    output_contexts: List = None,
    kendra_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an intent. To define the interaction between the user and your bot, you define one or more intents. For example, for a pizza ordering bot you would create an OrderPizza intent. When you create an intent, you must provide a name. You can optionally provide the following:   Sample utterances. For example, "I want to order a pizza" and "Can I order a pizza." You can't provide utterances for built-in intents.   Information to be gathered. You specify slots for the information that you bot requests from the user. You can specify standard slot types, such as date and time, or custom slot types for your application.   How the intent is fulfilled. You can provide a Lambda function or configure the intent to return the intent information to your client application. If you use a Lambda function, Amazon Lex invokes the function when all of the intent information is available.   A confirmation prompt to send to the user to confirm an intent. For example, "Shall I order your pizza?"   A conclusion statement to send to the user after the intent is fulfilled. For example, "I ordered your pizza."   A follow-up prompt that asks the user for additional activity. For example, "Do you want a drink with your pizza?"

    Args:
        intent_name(str): The name of the intent. Intent names must be unique in the locale that contains the intent and cannot match the name of any built-in intent.
        description(str, optional): A description of the intent. Use the description to help identify the intent in lists. Defaults to None.
        parent_intent_signature(str, optional): A unique identifier for the built-in intent to base this intent on. Defaults to None.
        sample_utterances(List, optional): An array of strings that a user might say to signal the intent. For example, "I want a pizza", or "I want a {PizzaSize} pizza".  In an utterance, slot names are enclosed in curly braces ("{", "}") to indicate where they should be displayed in the utterance shown to the user.. . Defaults to None.
        dialog_code_hook(Dict, optional): Specifies that Amazon Lex invokes the alias Lambda function for each user input. You can invoke this Lambda function to personalize user interaction. For example, suppose that your bot determines that the user's name is John. You Lambda function might retrieve John's information from a backend database and prepopulate some of the values. For example, if you find that John is gluten intolerant, you might set the corresponding intent slot, glutenIntolerant to true. You might find John's phone number and set the corresponding session attribute. Defaults to None.
        fulfillment_code_hook(Dict, optional): Specifies that Amazon Lex invokes the alias Lambda function when the intent is ready for fulfillment. You can invoke this function to complete the bot's transaction with the user. For example, in a pizza ordering bot, the Lambda function can look up the closest pizza restaurant to the customer's location and then place an order on the customer's behalf. Defaults to None.
        intent_confirmation_setting(Dict, optional): Provides prompts that Amazon Lex sends to the user to confirm the completion of an intent. If the user answers "no," the settings contain a statement that is sent to the user to end the intent. Defaults to None.
        intent_closing_setting(Dict, optional): Sets the response that Amazon Lex sends to the user when the intent is closed. Defaults to None.
        input_contexts(List, optional): A list of contexts that must be active for this intent to be considered by Amazon Lex. When an intent has an input context list, Amazon Lex only considers using the intent in an interaction with the user when the specified contexts are included in the active context list for the session. If the contexts are not active, then Amazon Lex will not use the intent. A context can be automatically activated using the outputContexts property or it can be set at runtime.  For example, if there are two intents with different input contexts that respond to the same utterances, only the intent with the active context will respond. An intent may have up to 5 input contexts. If an intent has multiple input contexts, all of the contexts must be active to consider the intent. Defaults to None.
        output_contexts(List, optional): A lists of contexts that the intent activates when it is fulfilled. You can use an output context to indicate the intents that Amazon Lex should consider for the next turn of the conversation with a customer.  When you use the outputContextsList property, all of the contexts specified in the list are activated when the intent is fulfilled. You can set up to 10 output contexts. You can also set the number of conversation turns that the context should be active, or the length of time that the context should be active. Defaults to None.
        kendra_configuration(Dict, optional): Configuration information required to use the AMAZON.KendraSearchIntent intent to connect to an Amazon Kendra index. The AMAZON.KendraSearchIntent intent is called when Amazon Lex can't determine another intent to invoke. Defaults to None.
        bot_id(str): The identifier of the bot associated with this intent.
        bot_version(str): The identifier of the version of the bot associated with this intent.
        locale_id(str): The identifier of the language and locale where this intent is used. All of the bots, slot types, and slots used by the intent must have the same locale. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.intent.create(
                ctx, intent_name=value, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.intent.create intent_name=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_intent",
        op_kwargs={
            "intentName": intent_name,
            "description": description,
            "parentIntentSignature": parent_intent_signature,
            "sampleUtterances": sample_utterances,
            "dialogCodeHook": dialog_code_hook,
            "fulfillmentCodeHook": fulfillment_code_hook,
            "intentConfirmationSetting": intent_confirmation_setting,
            "intentClosingSetting": intent_closing_setting,
            "inputContexts": input_contexts,
            "outputContexts": output_contexts,
            "kendraConfiguration": kendra_configuration,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )


async def delete(
    hub, ctx, intent_id: str, bot_id: str, bot_version: str, locale_id: str
) -> None:
    r"""
    **Autogenerated function**

    Removes the specified intent. Deleting an intent also deletes the slots associated with the intent.

    Args:
        intent_id(str): The unique identifier of the intent to delete.
        bot_id(str): The identifier of the bot associated with the intent.
        bot_version(str): The version of the bot associated with the intent.
        locale_id(str): The identifier of the language and locale where the bot will be deleted. The string must match one of the supported locales. For more information, see Supported languages.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.intent.delete(
                ctx, intent_id=value, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.intent.delete intent_id=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_intent",
        op_kwargs={
            "intentId": intent_id,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )


async def describe(
    hub, ctx, intent_id: str, bot_id: str, bot_version: str, locale_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about an intent.

    Args:
        intent_id(str): The identifier of the intent to describe.
        bot_id(str): The identifier of the bot associated with the intent.
        bot_version(str): The version of the bot associated with the intent.
        locale_id(str): The identifier of the language and locale of the intent to describe. The string must match one of the supported locales. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.intent.describe(
                ctx, intent_id=value, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.intent.describe intent_id=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_intent",
        op_kwargs={
            "intentId": intent_id,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )


async def list_all(
    hub,
    ctx,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get a list of intents that meet the specified criteria.

    Args:
        bot_id(str): The unique identifier of the bot that contains the intent.
        bot_version(str): The version of the bot that contains the intent.
        locale_id(str): The identifier of the language and locale of the intents to list. The string must match one of the supported locales. For more information, see Supported languages.
        sort_by(Dict, optional): Determines the sort order for the response from the ListIntents operation. You can choose to sort by the intent name or last updated date in either ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification of a filter used to limit the intents in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on. Defaults to None.
        max_results(int, optional): The maximum number of intents to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListIntents operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.intent.list_all(
                ctx, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.intent.list_all bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_intents",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    intent_id: str,
    intent_name: str,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    description: str = None,
    parent_intent_signature: str = None,
    sample_utterances: List = None,
    dialog_code_hook: Dict = None,
    fulfillment_code_hook: Dict = None,
    slot_priorities: List = None,
    intent_confirmation_setting: Dict = None,
    intent_closing_setting: Dict = None,
    input_contexts: List = None,
    output_contexts: List = None,
    kendra_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the settings for an intent.

    Args:
        intent_id(str): The unique identifier of the intent to update.
        intent_name(str): The new name for the intent.
        description(str, optional): The new description of the intent. Defaults to None.
        parent_intent_signature(str, optional): The signature of the new built-in intent to use as the parent of this intent. Defaults to None.
        sample_utterances(List, optional): New utterances used to invoke the intent. Defaults to None.
        dialog_code_hook(Dict, optional): The new Lambda function to use between each turn of the conversation with the bot. Defaults to None.
        fulfillment_code_hook(Dict, optional): The new Lambda function to call when all of the intents required slots are provided and the intent is ready for fulfillment. Defaults to None.
        slot_priorities(List, optional): A new list of slots and their priorities that are contained by the intent. Defaults to None.
        intent_confirmation_setting(Dict, optional): New prompts that Amazon Lex sends to the user to confirm the completion of an intent. Defaults to None.
        intent_closing_setting(Dict, optional): The new response that Amazon Lex sends the user when the intent is closed. Defaults to None.
        input_contexts(List, optional): A new list of contexts that must be active in order for Amazon Lex to consider the intent. Defaults to None.
        output_contexts(List, optional): A new list of contexts that Amazon Lex activates when the intent is fulfilled. Defaults to None.
        kendra_configuration(Dict, optional): New configuration settings for connecting to an Amazon Kendra index. Defaults to None.
        bot_id(str): The identifier of the bot that contains the intent.
        bot_version(str): The version of the bot that contains the intent. Must be DRAFT.
        locale_id(str): The identifier of the language and locale where this intent is used. The string must match one of the supported locales. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.intent.update(
                ctx,
                intent_id=value,
                intent_name=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.intent.update intent_id=value, intent_name=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_intent",
        op_kwargs={
            "intentId": intent_id,
            "intentName": intent_name,
            "description": description,
            "parentIntentSignature": parent_intent_signature,
            "sampleUtterances": sample_utterances,
            "dialogCodeHook": dialog_code_hook,
            "fulfillmentCodeHook": fulfillment_code_hook,
            "slotPriorities": slot_priorities,
            "intentConfirmationSetting": intent_confirmation_setting,
            "intentClosingSetting": intent_closing_setting,
            "inputContexts": input_contexts,
            "outputContexts": output_contexts,
            "kendraConfiguration": kendra_configuration,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, account_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves settings for the specified user ID, such as any associated phone number settings.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.setting.get_all(ctx, account_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.setting.get_all account_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_user_settings",
        op_kwargs={"AccountId": account_id, "UserId": user_id},
    )


async def update_multiple(
    hub, ctx, account_id: str, user_id: str, user_settings: Dict
) -> None:
    r"""
    **Autogenerated function**

    Updates the settings for the specified user, such as phone number settings.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.
        user_settings(Dict): The user settings to update.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.setting.update_multiple(
                ctx, account_id=value, user_id=value, user_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.setting.update_multiple account_id=value, user_id=value, user_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_user_settings",
        op_kwargs={
            "AccountId": account_id,
            "UserId": user_id,
            "UserSettings": user_settings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    kms_key_id: str = None,
    tags: Dict = None,
    federation_mode: str = None,
    federation_parameters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new FinSpace environment.

    Args:
        name(str): The name of the FinSpace environment to be created.
        description(str, optional): The description of the FinSpace environment to be created. Defaults to None.
        kms_key_id(str, optional): The KMS key id to encrypt your data in the FinSpace environment. Defaults to None.
        tags(Dict, optional): Add tags to your FinSpace environment. Defaults to None.
        federation_mode(str, optional): Authentication mode for the environment.    FEDERATED - Users access FinSpace through Single Sign On (SSO) via your Identity provider.    LOCAL - Users access FinSpace via email and password managed within the FinSpace environment.  . Defaults to None.
        federation_parameters(Dict, optional): Configuration information when authentication mode is FEDERATED. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace.environment.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace.environment.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace",
        operation="create_environment",
        op_kwargs={
            "name": name,
            "description": description,
            "kmsKeyId": kms_key_id,
            "tags": tags,
            "federationMode": federation_mode,
            "federationParameters": federation_parameters,
        },
    )


async def delete(hub, ctx, environment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an FinSpace environment.

    Args:
        environment_id(str): The identifier for the FinSpace environment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace.environment.delete(ctx, environment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace.environment.delete environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace",
        operation="delete_environment",
        op_kwargs={"environmentId": environment_id},
    )


async def get(hub, ctx, environment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the FinSpace environment object.

    Args:
        environment_id(str): The identifier of the FinSpace environment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace.environment.get(ctx, environment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace.environment.get environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace",
        operation="get_environment",
        op_kwargs={"environmentId": environment_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    A list of all of your FinSpace environments.

    Args:
        next_token(str, optional): A token generated by FinSpace that specifies where to continue pagination if a previous request was truncated. To get the next set of pages, pass in the nextToken value from the response object of the previous page call. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace.environment.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace.environment.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace",
        operation="list_environments",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    environment_id: str,
    name: str = None,
    description: str = None,
    federation_mode: str = None,
    federation_parameters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update your FinSpace environment.

    Args:
        environment_id(str): The identifier of the FinSpace environment.
        name(str, optional): The name of the environment. Defaults to None.
        description(str, optional): The description of the environment. Defaults to None.
        federation_mode(str, optional): Authentication mode for the environment.    FEDERATED - Users access FinSpace through Single Sign On (SSO) via your Identity provider.    LOCAL - Users access FinSpace via email and password managed within the FinSpace environment.  . Defaults to None.
        federation_parameters(Dict, optional): Configuration information when authentication mode is FEDERATED. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace.environment.update(ctx, environment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace.environment.update environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace",
        operation="update_environment",
        op_kwargs={
            "environmentId": environment_id,
            "name": name,
            "description": description,
            "federationMode": federation_mode,
            "federationParameters": federation_parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the gateway's local disks. To specify which gateway to describe, you use the Amazon Resource Name (ARN) of the gateway in the body of the request. The request returns a list of all disks, specifying which are configured as working storage, cache storage, or stored volume or not configured at all. The response includes a DiskStatus field. This field can have a value of present (the disk is available to use), missing (the disk is no longer connected to the gateway), or mismatch (the disk node is occupied by a disk that has incorrect metadata or the disk content is corrupted).

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.local.disk.list_all(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.local.disk.list_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_local_disks",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(hub, ctx, suppressed_reasons: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Change the settings for the account-level suppression list.

    Args:
        suppressed_reasons(List, optional): A list that contains the reasons that email addresses will be automatically added to the suppression list for your account. This list can contain any or all of the following:    COMPLAINT – Amazon SES adds an email address to the suppression list for your account when a message sent to that address results in a complaint.    BOUNCE – Amazon SES adds an email address to the suppression list for your account when a message sent to that address results in a hard bounce.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.account.suppression_attribute.put_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.account.suppression_attribute.put_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_account_suppression_attributes",
        op_kwargs={"SuppressedReasons": suppressed_reasons},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, channel_arn: str, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a stream key, used to initiate a stream, for the specified channel ARN. Note that CreateChannel creates a stream key. If you subsequently use CreateStreamKey on the same channel, it will fail because a stream key already exists and there is a limit of 1 stream key per channel. To reset the stream key on a channel, use DeleteStreamKey and then CreateStreamKey.

    Args:
        channel_arn(str): ARN of the channel for which to create the stream key.
        tags(Dict, optional): Array of 1-50 maps, each of the form string:string (key:value). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.key.create(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.key.create channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="create_stream_key",
        op_kwargs={"channelArn": channel_arn, "tags": tags},
    )


async def delete(hub, ctx, arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the stream key for the specified ARN, so it can no longer be used to stream.

    Args:
        arn(str): ARN of the stream key to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.key.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.key.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ivs", operation="delete_stream_key", op_kwargs={"arn": arn}
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets stream-key information for a specified ARN.

    Args:
        arn(str): ARN for the stream key to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.key.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.key.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ivs", operation="get_stream_key", op_kwargs={"arn": arn}
    )


async def list_all(
    hub, ctx, channel_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about stream keys for the specified channel.

    Args:
        channel_arn(str): Channel ARN used to filter the list.
        next_token(str, optional): The first stream key to retrieve. This is used for pagination; see the nextToken response field. Defaults to None.
        max_results(int, optional): Maximum number of streamKeys to return. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.key.list_all(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.key.list_all channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="list_stream_keys",
        op_kwargs={
            "channelArn": channel_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, registry_name: str, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new registry which may be used to hold a collection of schemas.

    Args:
        registry_name(str): Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark. No whitespace.
        description(str, optional): A description of the registry. If description is not provided, there will not be any default value for this. Defaults to None.
        tags(Dict, optional): Amazon Web Services tags that contain a key value pair and may be searched by console, command line, or API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.registry.create(ctx, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.registry.create registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_registry",
        op_kwargs={
            "RegistryName": registry_name,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, registry_id: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Delete the entire registry including schema and all of its versions. To get the status of the delete operation, you can call the GetRegistry API after the asynchronous call. Deleting a registry will deactivate all online operations for the registry such as the UpdateRegistry, CreateSchema, UpdateSchema, and RegisterSchemaVersion APIs.

    Args:
        registry_id(Dict): This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.registry.delete(ctx, registry_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.registry.delete registry_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_registry",
        op_kwargs={"RegistryId": registry_id},
    )


async def get(hub, ctx, registry_id: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified registry in detail.

    Args:
        registry_id(Dict): This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.registry.get(ctx, registry_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.registry.get registry_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_registry",
        op_kwargs={"RegistryId": registry_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of registries that you have created, with minimal registry information. Registries in the Deleting status will not be included in the results. Empty results will be returned if there are no registries available.

    Args:
        max_results(int, optional): Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.registry.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.registry.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_registries",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, registry_id: Dict, description: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing registry which is used to hold a collection of schemas. The updated properties relate to the registry, and do not modify any of the schemas within the registry.

    Args:
        registry_id(Dict): This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
        description(str): A description of the registry. If description is not provided, this field will not be updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.registry.update(ctx, registry_id=value, description=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.registry.update registry_id=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_registry",
        op_kwargs={"RegistryId": registry_id, "Description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def execute(
    hub,
    ctx,
    statement: str,
    parameters: List = None,
    consistent_read: bool = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation allows you to perform reads and singleton writes on data stored in DynamoDB, using PartiQL.

    Args:
        statement(str):  The PartiQL statement representing the operation to run. .
        parameters(List, optional):  The parameters for the PartiQL statement, if any. . Defaults to None.
        consistent_read(bool, optional):  The consistency of a read operation. If set to true, then a strongly consistent read is used; otherwise, an eventually consistent read is used. . Defaults to None.
        next_token(str, optional):  Set this value to get remaining results, if NextToken was returned in the statement response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.statement.execute(ctx, statement=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.statement.execute statement=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="execute_statement",
        op_kwargs={
            "Statement": statement,
            "Parameters": parameters,
            "ConsistentRead": consistent_read,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, id_: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the S3 Intelligent-Tiering configuration from the specified bucket. The S3 Intelligent-Tiering storage class is designed to optimize storage costs by automatically moving data to the most cost-effective storage access tier, without additional operational overhead. S3 Intelligent-Tiering delivers automatic cost savings by moving data between access tiers, when access patterns change. The S3 Intelligent-Tiering storage class is suitable for objects larger than 128 KB that you plan to store for at least 30 days. If the size of an object is less than 128 KB, it is not eligible for auto-tiering. Smaller objects can be stored, but they are always charged at the frequent access tier rates in the S3 Intelligent-Tiering storage class.  If you delete an object before the end of the 30-day minimum storage duration period, you are charged for 30 days. For more information, see Storage class for automatically optimizing frequently and infrequently accessed objects. Operations related to DeleteBucketIntelligentTieringConfiguration include:     GetBucketIntelligentTieringConfiguration     PutBucketIntelligentTieringConfiguration     ListBucketIntelligentTieringConfigurations

    Args:
        bucket(str): The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
        id_(str): The ID used to identify the S3 Intelligent-Tiering configuration.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.intelligent_tiering_configuration.delete(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.intelligent_tiering_configuration.delete bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_intelligent_tiering_configuration",
        op_kwargs={"Bucket": bucket, "Id": id_},
    )


async def get(hub, ctx, bucket: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the S3 Intelligent-Tiering configuration from the specified bucket. The S3 Intelligent-Tiering storage class is designed to optimize storage costs by automatically moving data to the most cost-effective storage access tier, without additional operational overhead. S3 Intelligent-Tiering delivers automatic cost savings by moving data between access tiers, when access patterns change. The S3 Intelligent-Tiering storage class is suitable for objects larger than 128 KB that you plan to store for at least 30 days. If the size of an object is less than 128 KB, it is not eligible for auto-tiering. Smaller objects can be stored, but they are always charged at the frequent access tier rates in the S3 Intelligent-Tiering storage class.  If you delete an object before the end of the 30-day minimum storage duration period, you are charged for 30 days. For more information, see Storage class for automatically optimizing frequently and infrequently accessed objects. Operations related to GetBucketIntelligentTieringConfiguration include:     DeleteBucketIntelligentTieringConfiguration     PutBucketIntelligentTieringConfiguration     ListBucketIntelligentTieringConfigurations

    Args:
        bucket(str): The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
        id_(str): The ID used to identify the S3 Intelligent-Tiering configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.intelligent_tiering_configuration.get(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.intelligent_tiering_configuration.get bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_intelligent_tiering_configuration",
        op_kwargs={"Bucket": bucket, "Id": id_},
    )


async def list_all(hub, ctx, bucket: str, continuation_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the S3 Intelligent-Tiering configuration from the specified bucket. The S3 Intelligent-Tiering storage class is designed to optimize storage costs by automatically moving data to the most cost-effective storage access tier, without additional operational overhead. S3 Intelligent-Tiering delivers automatic cost savings by moving data between access tiers, when access patterns change. The S3 Intelligent-Tiering storage class is suitable for objects larger than 128 KB that you plan to store for at least 30 days. If the size of an object is less than 128 KB, it is not eligible for auto-tiering. Smaller objects can be stored, but they are always charged at the frequent access tier rates in the S3 Intelligent-Tiering storage class.  If you delete an object before the end of the 30-day minimum storage duration period, you are charged for 30 days. For more information, see Storage class for automatically optimizing frequently and infrequently accessed objects. Operations related to ListBucketIntelligentTieringConfigurations include:     DeleteBucketIntelligentTieringConfiguration     PutBucketIntelligentTieringConfiguration     GetBucketIntelligentTieringConfiguration

    Args:
        bucket(str): The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
        continuation_token(str, optional): The ContinuationToken that represents a placeholder from where this request should begin. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.intelligent_tiering_configuration.list_all(
                ctx, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.intelligent_tiering_configuration.list_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="list_bucket_intelligent_tiering_configurations",
        op_kwargs={"Bucket": bucket, "ContinuationToken": continuation_token},
    )


async def put(
    hub, ctx, bucket: str, id_: str, intelligent_tiering_configuration: Dict
) -> None:
    r"""
    **Autogenerated function**

    Puts a S3 Intelligent-Tiering configuration to the specified bucket. You can have up to 1,000 S3 Intelligent-Tiering configurations per bucket. The S3 Intelligent-Tiering storage class is designed to optimize storage costs by automatically moving data to the most cost-effective storage access tier, without additional operational overhead. S3 Intelligent-Tiering delivers automatic cost savings by moving data between access tiers, when access patterns change. The S3 Intelligent-Tiering storage class is suitable for objects larger than 128 KB that you plan to store for at least 30 days. If the size of an object is less than 128 KB, it is not eligible for auto-tiering. Smaller objects can be stored, but they are always charged at the frequent access tier rates in the S3 Intelligent-Tiering storage class.  If you delete an object before the end of the 30-day minimum storage duration period, you are charged for 30 days. For more information, see Storage class for automatically optimizing frequently and infrequently accessed objects. Operations related to PutBucketIntelligentTieringConfiguration include:     DeleteBucketIntelligentTieringConfiguration     GetBucketIntelligentTieringConfiguration     ListBucketIntelligentTieringConfigurations     You only need S3 Intelligent-Tiering enabled on a bucket if you want to automatically move objects stored in the S3 Intelligent-Tiering storage class to the Archive Access or Deep Archive Access tier.   Special Errors     HTTP 400 Bad Request Error     Code: InvalidArgument    Cause: Invalid Argument      HTTP 400 Bad Request Error     Code: TooManyConfigurations    Cause: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.       HTTP 403 Forbidden Error     Code: AccessDenied    Cause: You are not the owner of the specified bucket, or you do not have the s3:PutIntelligentTieringConfiguration bucket permission to set the configuration on the bucket.

    Args:
        bucket(str): The name of the Amazon S3 bucket whose configuration you want to modify or retrieve.
        id_(str): The ID used to identify the S3 Intelligent-Tiering configuration.
        intelligent_tiering_configuration(Dict): Container for S3 Intelligent-Tiering configuration.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.intelligent_tiering_configuration.put(
                ctx, bucket=value, id_=value, intelligent_tiering_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.intelligent_tiering_configuration.put bucket=value, id_=value, intelligent_tiering_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_intelligent_tiering_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "IntelligentTieringConfiguration": intelligent_tiering_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, job_name: str, run_id: str, predecessors_included: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the metadata for a given job run.

    Args:
        job_name(str): Name of the job definition being run.
        run_id(str): The ID of the job run.
        predecessors_included(bool, optional): True if a list of predecessor runs should be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.run.get(ctx, job_name=value, run_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.run.get job_name=value, run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_job_run",
        op_kwargs={
            "JobName": job_name,
            "RunId": run_id,
            "PredecessorsIncluded": predecessors_included,
        },
    )


async def get_all(
    hub, ctx, job_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata for all runs of a given job definition.

    Args:
        job_name(str): The name of the job definition for which to retrieve all job runs.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.
        max_results(int, optional): The maximum size of the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.run.get_all(ctx, job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.run.get_all job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_job_runs",
        op_kwargs={
            "JobName": job_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    job_name: str,
    job_run_id: str = None,
    arguments: Dict = None,
    allocated_capacity: int = None,
    timeout: int = None,
    max_capacity: float = None,
    security_configuration: str = None,
    notification_property: Dict = None,
    worker_type: str = None,
    number_of_workers: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a job run using a job definition.

    Args:
        job_name(str): The name of the job definition to use.
        job_run_id(str, optional): The ID of a previous JobRun to retry. Defaults to None.
        arguments(Dict, optional): The job arguments specifically for this run. For this job run, they replace the default arguments set in the job definition itself. You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes. For information about how to specify and consume your own Job arguments, see the Calling Glue APIs in Python topic in the developer guide. For information about the key-value pairs that Glue consumes to set up your job, see the Special Parameters Used by Glue topic in the developer guide. Defaults to None.
        allocated_capacity(int, optional): This field is deprecated. Use MaxCapacity instead. The number of Glue data processing units (DPUs) to allocate to this JobRun. From 2 to 100 DPUs can be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page. Defaults to None.
        timeout(int, optional): The JobRun timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours). This overrides the timeout value set in the parent job. Defaults to None.
        max_capacity(float, optional): The number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page. Do not set Max Capacity if using WorkerType and NumberOfWorkers. The value that can be allocated for MaxCapacity depends on whether you are running a Python shell job, or an Apache Spark ETL job:   When you specify a Python shell job (JobCommand.Name="pythonshell"), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.   When you specify an Apache Spark ETL job (JobCommand.Name="glueetl"), you can allocate from 2 to 100 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.  . Defaults to None.
        security_configuration(str, optional): The name of the SecurityConfiguration structure to be used with this job run. Defaults to None.
        notification_property(Dict, optional): Specifies configuration properties of a job run notification. Defaults to None.
        worker_type(str, optional): The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.   For the Standard worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.   For the G.1X worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.   For the G.2X worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.  . Defaults to None.
        number_of_workers(int, optional): The number of workers of a defined workerType that are allocated when a job runs. The maximum number of workers you can define are 299 for G.1X, and 149 for G.2X. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.run.start(ctx, job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.run.start job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="start_job_run",
        op_kwargs={
            "JobName": job_name,
            "JobRunId": job_run_id,
            "Arguments": arguments,
            "AllocatedCapacity": allocated_capacity,
            "Timeout": timeout,
            "MaxCapacity": max_capacity,
            "SecurityConfiguration": security_configuration,
            "NotificationProperty": notification_property,
            "WorkerType": worker_type,
            "NumberOfWorkers": number_of_workers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, connection_id: str, lag_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates an existing connection with a link aggregation group (LAG). The connection is interrupted and re-established as a member of the LAG (connectivity to Amazon Web Services is interrupted). The connection must be hosted on the same Direct Connect endpoint as the LAG, and its bandwidth must match the bandwidth for the LAG. You can re-associate a connection that's currently associated with a different LAG; however, if removing the connection would cause the original LAG to fall below its setting for minimum number of operational connections, the request fails. Any virtual interfaces that are directly associated with the connection are automatically re-associated with the LAG. If the connection was originally associated with a different LAG, the virtual interfaces remain associated with the original LAG. For interconnects, any hosted connections are automatically re-associated with the LAG. If the interconnect was originally associated with a different LAG, the hosted connections remain associated with the original LAG.

    Args:
        connection_id(str): The ID of the connection.
        lag_id(str): The ID of the LAG with which to associate the connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.with_lag.associate(
                ctx, connection_id=value, lag_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.with_lag.associate connection_id=value, lag_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="associate_connection_with_lag",
        op_kwargs={"connectionId": connection_id, "lagId": lag_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    content: str,
    registry_name: str,
    schema_name: str,
    type_: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a schema definition. Inactive schemas will be deleted after two years.

    Args:
        content(str): The source of the schema definition.
        description(str, optional): A description of the schema. Defaults to None.
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        tags(Dict, optional): Tags associated with the schema. Defaults to None.
        type_(str): The type of schema.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.init.create(
                ctx, content=value, registry_name=value, schema_name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.init.create content=value, registry_name=value, schema_name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="create_schema",
        op_kwargs={
            "Content": content,
            "Description": description,
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "Tags": tags,
            "Type": type_,
        },
    )


async def delete(hub, ctx, registry_name: str, schema_name: str) -> None:
    r"""
    **Autogenerated function**

    Delete a schema definition.

    Args:
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.init.delete(
                ctx, registry_name=value, schema_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.init.delete registry_name=value, schema_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="delete_schema",
        op_kwargs={"RegistryName": registry_name, "SchemaName": schema_name},
    )


async def describe(
    hub, ctx, registry_name: str, schema_name: str, schema_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve the schema definition.

    Args:
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        schema_version(str, optional): Specifying this limits the results to only this schema version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.init.describe(
                ctx, registry_name=value, schema_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.init.describe registry_name=value, schema_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="describe_schema",
        op_kwargs={
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "SchemaVersion": schema_version,
        },
    )


async def export(
    hub,
    ctx,
    registry_name: str,
    schema_name: str,
    type_: str,
    schema_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        schema_version(str, optional): Specifying this limits the results to only this schema version. Defaults to None.
        type_(str): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.init.export(
                ctx, registry_name=value, schema_name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.init.export registry_name=value, schema_name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="export_schema",
        op_kwargs={
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "SchemaVersion": schema_version,
            "Type": type_,
        },
    )


async def update(
    hub,
    ctx,
    registry_name: str,
    schema_name: str,
    client_token_id: str = None,
    content: str = None,
    description: str = None,
    type_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the schema definition Inactive schemas will be deleted after two years.

    Args:
        client_token_id(str, optional): The ID of the client token. Defaults to None.
        content(str, optional): The source of the schema definition. Defaults to None.
        description(str, optional): The description of the schema. Defaults to None.
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        type_(str, optional): The schema type for the events schema. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.init.update(
                ctx, registry_name=value, schema_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.init.update registry_name=value, schema_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="update_schema",
        op_kwargs={
            "ClientTokenId": client_token_id,
            "Content": content,
            "Description": description,
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "Type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, accelerator_arn: str, port_ranges: List, idempotency_token: str
) -> Dict:
    r"""
    **Autogenerated function**

    Create a listener to process inbound connections from clients to a custom routing accelerator. Connections arrive to assigned static IP addresses on the port range that you specify.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the accelerator for a custom routing listener.
        port_ranges(List): The port range to support for connections from clients to your accelerator. Separately, you set port ranges for endpoints. For more information, see About endpoints for custom routing accelerators.
        idempotency_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the uniqueness—of the request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.listener.create(
                ctx, accelerator_arn=value, port_ranges=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.listener.create accelerator_arn=value, port_ranges=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="create_custom_routing_listener",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "PortRanges": port_ranges,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, listener_arn: str) -> None:
    r"""
    **Autogenerated function**

    Delete a listener for a custom routing accelerator.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.listener.delete(
                ctx, listener_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.listener.delete listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="delete_custom_routing_listener",
        op_kwargs={"ListenerArn": listener_arn},
    )


async def describe(hub, ctx, listener_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    The description of a listener for a custom routing accelerator.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.listener.describe(
                ctx, listener_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.listener.describe listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="describe_custom_routing_listener",
        op_kwargs={"ListenerArn": listener_arn},
    )


async def list_all(
    hub, ctx, accelerator_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the listeners for a custom routing accelerator.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the accelerator to list listeners for.
        max_results(int, optional): The number of listener objects that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.listener.list_all(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.listener.list_all accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_custom_routing_listeners",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, listener_arn: str, port_ranges: List) -> Dict:
    r"""
    **Autogenerated function**

    Update a listener for a custom routing accelerator.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener to update.
        port_ranges(List): The updated port range to support for connections from clients to your accelerator. If you remove ports that are currently being used by a subnet endpoint, the call fails. Separately, you set port ranges for endpoints. For more information, see About endpoints for custom routing accelerators.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.listener.update(
                ctx, listener_arn=value, port_ranges=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.listener.update listener_arn=value, port_ranges=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="update_custom_routing_listener",
        op_kwargs={"ListenerArn": listener_arn, "PortRanges": port_ranges},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    fleet_name: str,
    display_name: str = None,
    optimize_for_end_user_location: bool = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a fleet. A fleet consists of resources and the configuration that delivers associated websites to authorized users who download and set up the Amazon WorkLink app.

    Args:
        fleet_name(str): A unique name for the fleet.
        display_name(str, optional): The fleet name to display. Defaults to None.
        optimize_for_end_user_location(bool, optional): The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region. Defaults to None.
        tags(Dict, optional):  The tags to add to the resource. A tag is a key-value pair. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.fleet.init.create(ctx, fleet_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.fleet.init.create fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="create_fleet",
        op_kwargs={
            "FleetName": fleet_name,
            "DisplayName": display_name,
            "OptimizeForEndUserLocation": optimize_for_end_user_location,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, fleet_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a fleet. Prevents users from accessing previously associated websites.

    Args:
        fleet_arn(str): The ARN of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.fleet.init.delete(ctx, fleet_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.fleet.init.delete fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="delete_fleet",
        op_kwargs={"FleetArn": fleet_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of fleets for the current account and Region.

    Args:
        next_token(str, optional): The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        max_results(int, optional): The maximum number of results to be included in the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.fleet.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.fleet.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="list_fleets",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub, ctx, destination_region: str, backup_id: str, tag_list: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Copy an AWS CloudHSM cluster backup to a different region.

    Args:
        destination_region(str): The AWS region that will contain your copied CloudHSM cluster backup.
        backup_id(str): The ID of the backup that will be copied to the destination region. .
        tag_list(List, optional): Tags to apply to the destination backup during creation. If you specify tags, only these tags will be applied to the destination backup. If you do not specify tags, the service copies tags from the source backup to the destination backup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.backup.to_region.copy(
                ctx, destination_region=value, backup_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.backup.to_region.copy destination_region=value, backup_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="copy_backup_to_region",
        op_kwargs={
            "DestinationRegion": destination_region,
            "BackupId": backup_id,
            "TagList": tag_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, partner_account_id: str, partner_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a partner account. If PartnerAccountId and PartnerType are null, returns all partner accounts.

    Args:
        partner_account_id(str): The partner account ID to disassociate from the AWS account.
        partner_type(str): The partner type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.partner_account.get(
                ctx, partner_account_id=value, partner_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.partner_account.get partner_account_id=value, partner_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_partner_account",
        op_kwargs={"PartnerAccountId": partner_account_id, "PartnerType": partner_type},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the partner accounts associated with your AWS account.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.partner_account.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.partner_account.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="list_partner_accounts",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub, ctx, sidewalk: Dict, partner_account_id: str, partner_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates properties of a partner account.

    Args:
        sidewalk(Dict): The Sidewalk account credentials.
        partner_account_id(str): The ID of the partner account to update.
        partner_type(str): The partner type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.partner_account.update(
                ctx, sidewalk=value, partner_account_id=value, partner_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.partner_account.update sidewalk=value, partner_account_id=value, partner_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="update_partner_account",
        op_kwargs={
            "Sidewalk": sidewalk,
            "PartnerAccountId": partner_account_id,
            "PartnerType": partner_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, instance_id: str, dry_run: bool = None, latest: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the console output for the specified instance. For Linux instances, the instance console output displays the exact console output that would normally be displayed on a physical monitor attached to a computer. For Windows instances, the instance console output includes the last three system event log errors. By default, the console output returns buffered information that was posted shortly after an instance transition state (start, stop, reboot, or terminate). This information is available for at least one hour after the most recent post. Only the most recent 64 KB of console output is available. You can optionally retrieve the latest serial console output at any time during the instance lifecycle. This option is supported on instance types that use the Nitro hypervisor. For more information, see Instance console output in the Amazon EC2 User Guide.

    Args:
        instance_id(str): The ID of the instance.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        latest(bool, optional): When enabled, retrieves the latest console output for the instance. Default: disabled (false). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.console.output.get(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.console.output.get instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_console_output",
        op_kwargs={"InstanceId": instance_id, "DryRun": dry_run, "Latest": latest},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, file_system_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the backup policy for the specified EFS file system.

    Args:
        file_system_id(str): Specifies which EFS file system to retrieve the BackupPolicy for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.backup_policy.describe(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.backup_policy.describe file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_backup_policy",
        op_kwargs={"FileSystemId": file_system_id},
    )


async def put(hub, ctx, file_system_id: str, backup_policy: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates the file system's backup policy. Use this action to start or stop automatic backups of the file system.

    Args:
        file_system_id(str): Specifies which EFS file system to update the backup policy for.
        backup_policy(Dict): The backup policy included in the PutBackupPolicy request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.backup_policy.put(
                ctx, file_system_id=value, backup_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.backup_policy.put file_system_id=value, backup_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="put_backup_policy",
        op_kwargs={"FileSystemId": file_system_id, "BackupPolicy": backup_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, check_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the results for the AWS Trusted Advisor check summaries for the check IDs that you specified. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation. The response contains an array of TrustedAdvisorCheckSummary objects.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        check_ids(List): The IDs of the Trusted Advisor checks.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.trusted_advisor_check.summary.describe_all(
                ctx, check_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.trusted_advisor_check.summary.describe_all check_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_trusted_advisor_check_summaries",
        op_kwargs={"checkIds": check_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    resource_owner: str,
    principal: str = None,
    resource_type: str = None,
    resource_arns: List = None,
    resource_share_arns: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the resources that you added to a resource shares or the resources that are shared with you.

    Args:
        resource_owner(str): The type of owner.
        principal(str, optional): The principal. Defaults to None.
        resource_type(str, optional): The resource type. Valid values: acm-pca:CertificateAuthority | appmesh:Mesh | codebuild:Project | codebuild:ReportGroup | ec2:CapacityReservation | ec2:DedicatedHost | ec2:LocalGatewayRouteTable | ec2:PrefixList | ec2:Subnet | ec2:TrafficMirrorTarget | ec2:TransitGateway | imagebuilder:Component | imagebuilder:Image | imagebuilder:ImageRecipe | imagebuilder:ContainerRecipe | glue:Catalog | glue:Database | glue:Table | license-manager:LicenseConfiguration I network-firewall:FirewallPolicy | network-firewall:StatefulRuleGroup | network-firewall:StatelessRuleGroup | outposts:Outpost | resource-groups:Group | rds:Cluster | route53resolver:ResolverQueryLogConfig | route53resolver:ResolverRule . Defaults to None.
        resource_arns(List, optional): The Amazon Resource Names (ARN) of the resources. Defaults to None.
        resource_share_arns(List, optional): The Amazon Resource Names (ARN) of the resource shares. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.init.list_all(ctx, resource_owner=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.init.list_all resource_owner=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="list_resources",
        op_kwargs={
            "resourceOwner": resource_owner,
            "principal": principal,
            "resourceType": resource_type,
            "resourceArns": resource_arns,
            "resourceShareArns": resource_share_arns,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def tag(hub, ctx, resource_share_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified tags to the specified resource share that you own.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        tags(List): One or more tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.init.tag(ctx, resource_share_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.init.tag resource_share_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="tag_resource",
        op_kwargs={"resourceShareArn": resource_share_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_share_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tags from the specified resource share that you own.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        tag_keys(List): The tag keys of the tags to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.init.untag(
                ctx, resource_share_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.init.untag resource_share_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="untag_resource",
        op_kwargs={"resourceShareArn": resource_share_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    List the tags for an Amazon ECR resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the only supported resource is an Amazon ECR repository.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="list_tags_for_resource",
        op_kwargs={"resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, configuration_set_name: str, event_destination: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a configuration set event destination.  When you create or update an event destination, you must provide one, and only one, destination. The destination can be CloudWatch, Amazon Kinesis Firehose, or Amazon Simple Notification Service (Amazon SNS).  An event destination is the AWS service to which Amazon SES publishes the email sending events associated with a configuration set. For information about using configuration sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set that the event destination should be associated with.
        event_destination(Dict): An object that describes the AWS service that email sending event information will be published to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.event_destination.create(
                ctx, configuration_set_name=value, event_destination=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.event_destination.create configuration_set_name=value, event_destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="create_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestination": event_destination,
        },
    )


async def delete(
    hub, ctx, configuration_set_name: str, event_destination_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a configuration set event destination. Configuration set event destinations are associated with configuration sets, which enable you to publish email sending events. For information about using configuration sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set from which to delete the event destination.
        event_destination_name(str): The name of the event destination to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.event_destination.delete(
                ctx, configuration_set_name=value, event_destination_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.event_destination.delete configuration_set_name=value, event_destination_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestinationName": event_destination_name,
        },
    )


async def update(
    hub, ctx, configuration_set_name: str, event_destination: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the event destination of a configuration set. Event destinations are associated with configuration sets, which enable you to publish email sending events to Amazon CloudWatch, Amazon Kinesis Firehose, or Amazon Simple Notification Service (Amazon SNS). For information about using configuration sets, see Monitoring Your Amazon SES Sending Activity in the Amazon SES Developer Guide.   When you create or update an event destination, you must provide one, and only one, destination. The destination can be Amazon CloudWatch, Amazon Kinesis Firehose, or Amazon Simple Notification Service (Amazon SNS).  You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set that contains the event destination that you want to update.
        event_destination(Dict): The event destination object that you want to apply to the specified configuration set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.event_destination.update(
                ctx, configuration_set_name=value, event_destination=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.event_destination.update configuration_set_name=value, event_destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="update_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestination": event_destination,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, arn: str, type_: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about artifacts.

    Args:
        arn(str): The run, job, suite, or test ARN.
        type_(str): The artifacts' type. Allowed values include:   FILE   LOG   SCREENSHOT  .
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.artifact.list_all(ctx, arn=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.artifact.list_all arn=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_artifacts",
        op_kwargs={"arn": arn, "type": type_, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def decrease(
    hub,
    ctx,
    replication_group_id: str,
    apply_immediately: bool,
    new_replica_count: int = None,
    replica_configuration: List = None,
    replicas_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Dynamically decreases the number of replicas in a Redis (cluster mode disabled) replication group or the number of replica nodes in one or more node groups (shards) of a Redis (cluster mode enabled) replication group. This operation is performed with no cluster down time.

    Args:
        replication_group_id(str): The id of the replication group from which you want to remove replica nodes.
        new_replica_count(int, optional): The number of read replica nodes you want at the completion of this operation. For Redis (cluster mode disabled) replication groups, this is the number of replica nodes in the replication group. For Redis (cluster mode enabled) replication groups, this is the number of replica nodes in each of the replication group's node groups. The minimum number of replicas in a shard or replication group is:   Redis (cluster mode disabled)   If Multi-AZ is enabled: 1   If Multi-AZ is not enabled: 0     Redis (cluster mode enabled): 0 (though you will not be able to failover to a replica if your primary node fails)  . Defaults to None.
        replica_configuration(List, optional): A list of ConfigureShard objects that can be used to configure each shard in a Redis (cluster mode enabled) replication group. The ConfigureShard has three members: NewReplicaCount, NodeGroupId, and PreferredAvailabilityZones. Defaults to None.
        replicas_to_remove(List, optional): A list of the node ids to remove from the replication group or node group (shard). Defaults to None.
        apply_immediately(bool): If True, the number of replica nodes is decreased immediately. ApplyImmediately=False is not currently supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.replica.count.decrease(
                ctx, replication_group_id=value, apply_immediately=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.replica.count.decrease replication_group_id=value, apply_immediately=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="decrease_replica_count",
        op_kwargs={
            "ReplicationGroupId": replication_group_id,
            "NewReplicaCount": new_replica_count,
            "ReplicaConfiguration": replica_configuration,
            "ReplicasToRemove": replicas_to_remove,
            "ApplyImmediately": apply_immediately,
        },
    )


async def increase(
    hub,
    ctx,
    replication_group_id: str,
    apply_immediately: bool,
    new_replica_count: int = None,
    replica_configuration: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Dynamically increases the number of replicas in a Redis (cluster mode disabled) replication group or the number of replica nodes in one or more node groups (shards) of a Redis (cluster mode enabled) replication group. This operation is performed with no cluster down time.

    Args:
        replication_group_id(str): The id of the replication group to which you want to add replica nodes.
        new_replica_count(int, optional): The number of read replica nodes you want at the completion of this operation. For Redis (cluster mode disabled) replication groups, this is the number of replica nodes in the replication group. For Redis (cluster mode enabled) replication groups, this is the number of replica nodes in each of the replication group's node groups. Defaults to None.
        replica_configuration(List, optional): A list of ConfigureShard objects that can be used to configure each shard in a Redis (cluster mode enabled) replication group. The ConfigureShard has three members: NewReplicaCount, NodeGroupId, and PreferredAvailabilityZones. Defaults to None.
        apply_immediately(bool): If True, the number of replica nodes is increased immediately. ApplyImmediately=False is not currently supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.replica.count.increase(
                ctx, replication_group_id=value, apply_immediately=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.replica.count.increase replication_group_id=value, apply_immediately=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="increase_replica_count",
        op_kwargs={
            "ReplicationGroupId": replication_group_id,
            "NewReplicaCount": new_replica_count,
            "ReplicaConfiguration": replica_configuration,
            "ApplyImmediately": apply_immediately,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def provide(hub, ctx, anomaly_id: str, feedback: str) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the feedback property of a given cost anomaly.

    Args:
        anomaly_id(str):  A cost anomaly ID. .
        feedback(str): Describes whether the cost anomaly was a planned activity or you considered it an anomaly. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.feedback.provide(
                ctx, anomaly_id=value, feedback=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.feedback.provide anomaly_id=value, feedback=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="provide_anomaly_feedback",
        op_kwargs={"AnomalyId": anomaly_id, "Feedback": feedback},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    mesh_name: str,
    route_name: str,
    spec: Dict,
    virtual_router_name: str,
    client_token: str = None,
    mesh_owner: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a route that is associated with a virtual router.  You can route several different protocols and define a retry policy for a route. Traffic can be routed to one or more virtual nodes. For more information about routes, see Routes.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh to create the route in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then the account that you specify must share the mesh with your account before you can create the resource in the service mesh. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        route_name(str): The name to use for the route.
        spec(Dict): The route specification to apply.
        tags(List, optional): Optional metadata that you can apply to the route to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.
        virtual_router_name(str): The name of the virtual router in which to create the route. If the virtual router is in a shared mesh, then you must be the owner of the virtual router resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.route.create(
                ctx, mesh_name=value, route_name=value, spec=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.route.create mesh_name=value, route_name=value, spec=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="create_route",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "routeName": route_name,
            "spec": spec,
            "tags": tags,
            "virtualRouterName": virtual_router_name,
        },
    )


async def delete(
    hub,
    ctx,
    mesh_name: str,
    route_name: str,
    virtual_router_name: str,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing route.

    Args:
        mesh_name(str): The name of the service mesh to delete the route in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        route_name(str): The name of the route to delete.
        virtual_router_name(str): The name of the virtual router to delete the route in.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.route.delete(
                ctx, mesh_name=value, route_name=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.route.delete mesh_name=value, route_name=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="delete_route",
        op_kwargs={
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "routeName": route_name,
            "virtualRouterName": virtual_router_name,
        },
    )


async def describe(
    hub,
    ctx,
    mesh_name: str,
    route_name: str,
    virtual_router_name: str,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing route.

    Args:
        mesh_name(str): The name of the service mesh that the route resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        route_name(str): The name of the route to describe.
        virtual_router_name(str): The name of the virtual router that the route is associated with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.route.describe(
                ctx, mesh_name=value, route_name=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.route.describe mesh_name=value, route_name=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="describe_route",
        op_kwargs={
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "routeName": route_name,
            "virtualRouterName": virtual_router_name,
        },
    )


async def list_all(
    hub,
    ctx,
    mesh_name: str,
    virtual_router_name: str,
    limit: int = None,
    mesh_owner: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing routes in a service mesh.

    Args:
        limit(int, optional): The maximum number of results returned by ListRoutes in paginated output. When you use this parameter, ListRoutes returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListRoutes request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListRoutes returns up to 100 results and a nextToken value if applicable. Defaults to None.
        mesh_name(str): The name of the service mesh to list routes in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListRoutes request where limit was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.
        virtual_router_name(str): The name of the virtual router to list routes in.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.route.list_all(
                ctx, mesh_name=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.route.list_all mesh_name=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="list_routes",
        op_kwargs={
            "limit": limit,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "nextToken": next_token,
            "virtualRouterName": virtual_router_name,
        },
    )


async def update(
    hub,
    ctx,
    mesh_name: str,
    route_name: str,
    spec: Dict,
    virtual_router_name: str,
    client_token: str = None,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing route for a specified service mesh and virtual router.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh that the route resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        route_name(str): The name of the route to update.
        spec(Dict): The new route specification to apply. This overwrites the existing data.
        virtual_router_name(str): The name of the virtual router that the route is associated with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.route.update(
                ctx, mesh_name=value, route_name=value, spec=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.route.update mesh_name=value, route_name=value, spec=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="update_route",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "routeName": route_name,
            "spec": spec,
            "virtualRouterName": virtual_router_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, account_id: str, bucket: str) -> None:
    r"""
    **Autogenerated function**

     This action deletes an Amazon S3 on Outposts bucket's tags. To delete an S3 bucket tags, see DeleteBucketTagging in the Amazon S3 API Reference.   Deletes the tags from the Outposts bucket. For more information, see Using Amazon S3 on Outposts in Amazon S3 User Guide. To use this action, you must have permission to perform the PutBucketTagging action. By default, the bucket owner has this permission and can grant this permission to others.  All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to DeleteBucketTagging:    GetBucketTagging     PutBucketTagging

    Args:
        account_id(str): The account ID of the Outposts bucket tag set to be removed.
        bucket(str): The bucket ARN that has the tag set to be removed. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.tagging.delete(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.tagging.delete account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_bucket_tagging",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def get(hub, ctx, account_id: str, bucket: str) -> Dict:
    r"""
    **Autogenerated function**

     This action gets an Amazon S3 on Outposts bucket's tags. To get an S3 bucket tags, see GetBucketTagging in the Amazon S3 API Reference.   Returns the tag set associated with the Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide. To use this action, you must have permission to perform the GetBucketTagging action. By default, the bucket owner has this permission and can grant this permission to others.  GetBucketTagging has the following special error:   Error code: NoSuchTagSetError    Description: There is no tag set associated with the bucket.     All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to GetBucketTagging:    PutBucketTagging     DeleteBucketTagging

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): Specifies the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.tagging.get(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.tagging.get account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_bucket_tagging",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def put(hub, ctx, account_id: str, bucket: str, tagging: Dict) -> None:
    r"""
    **Autogenerated function**

     This action puts tags on an Amazon S3 on Outposts bucket. To put tags on an S3 bucket, see PutBucketTagging in the Amazon S3 API Reference.   Sets the tags for an S3 on Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide. Use tags to organize your Amazon Web Services bill to reflect your own cost structure. To do this, sign up to get your account bill with tag key values included. Then, to see the cost of combined resources, organize your billing information according to resources with the same tag key values. For example, you can tag several resources with a specific application name, and then organize your billing information to see the total cost of that application across several services. For more information, see Cost allocation and tagging.  Within a bucket, if you add a tag that has the same key as an existing tag, the new value overwrites the old value. For more information, see  Using cost allocation in Amazon S3 bucket tags.  To use this action, you must have permissions to perform the s3-outposts:PutBucketTagging action. The Outposts bucket owner has this permission by default and can grant this permission to others. For more information about permissions, see  Permissions Related to Bucket Subresource Operations and Managing access permissions to your Amazon S3 resources.  PutBucketTagging has the following special errors:   Error code: InvalidTagError    Description: The tag provided was not a valid tag. This error can occur if the tag did not pass input validation. For information about tag restrictions, see  User-Defined Tag Restrictions and  Amazon Web Services-Generated Cost Allocation Tag Restrictions.     Error code: MalformedXMLError    Description: The XML provided does not match the schema.     Error code: OperationAbortedError     Description: A conflicting conditional action is currently in progress against this resource. Try again.     Error code: InternalError    Description: The service was unable to apply the provided tag to the bucket.     All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to PutBucketTagging:    GetBucketTagging     DeleteBucketTagging

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): The Amazon Resource Name (ARN) of the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
        tagging(Dict): .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.tagging.put(
                ctx, account_id=value, bucket=value, tagging=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.tagging.put account_id=value, bucket=value, tagging=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_bucket_tagging",
        op_kwargs={"AccountId": account_id, "Bucket": bucket, "Tagging": tagging},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, volume_arn: str, snapshot_description: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a snapshot of a gateway from a volume recovery point. This operation is only supported in the cached volume gateway type. A volume recovery point is a point in time at which all data of the volume is consistent and from which you can create a snapshot. To get a list of volume recovery point for cached volume gateway, use ListVolumeRecoveryPoints. In the CreateSnapshotFromVolumeRecoveryPoint request, you identify the volume by providing its Amazon Resource Name (ARN). You must also provide a description for the snapshot. When the gateway takes a snapshot of the specified volume, the snapshot and its description appear in the Storage Gateway console. In response, the gateway returns you a snapshot ID. You can use this snapshot ID to check the snapshot progress or later use it when you want to create a volume from a snapshot.  To list or delete a snapshot, you must use the Amazon EC2 API. For more information, see DescribeSnapshots or DeleteSnapshot in the Amazon Elastic Compute Cloud API Reference.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the iSCSI volume target. Use the DescribeStorediSCSIVolumes operation to return to retrieve the TargetARN for specified VolumeARN.
        snapshot_description(str): Textual description of the snapshot that appears in the Amazon EC2 console, Elastic Block Store snapshots panel in the Description field, and in the Storage Gateway snapshot Details pane, Description field.
        tags(List, optional): A list of up to 50 tags that can be assigned to a snapshot. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.snapshot.from_volume_recovery_point.create(
                ctx, volume_arn=value, snapshot_description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.snapshot.from_volume_recovery_point.create volume_arn=value, snapshot_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_snapshot_from_volume_recovery_point",
        op_kwargs={
            "VolumeARN": volume_arn,
            "SnapshotDescription": snapshot_description,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    pipeline_execution_arn: str = None,
    next_token: str = None,
    max_results: int = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of PipeLineExecutionStep objects.

    Args:
        pipeline_execution_arn(str, optional): The Amazon Resource Name (ARN) of the pipeline execution. Defaults to None.
        next_token(str, optional): If the result of the previous ListPipelineExecutionSteps request was truncated, the response includes a NextToken. To retrieve the next set of pipeline execution steps, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of pipeline execution steps to return in the response. Defaults to None.
        sort_order(str, optional): The field by which to sort results. The default is CreatedTime. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.execution.step.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.execution.step.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_pipeline_execution_steps",
        op_kwargs={
            "PipelineExecutionArn": pipeline_execution_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, attribute: str, snapshot_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified attribute of the specified snapshot. You can specify only one attribute at a time. For more information about EBS snapshots, see Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.

    Args:
        attribute(str): The snapshot attribute you would like to view.
        snapshot_id(str): The ID of the EBS snapshot.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.snapshot.attribute.describe(
                ctx, attribute=value, snapshot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.snapshot.attribute.describe attribute=value, snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_snapshot_attribute",
        op_kwargs={
            "Attribute": attribute,
            "SnapshotId": snapshot_id,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub,
    ctx,
    snapshot_id: str,
    attribute: str = None,
    create_volume_permission: Dict = None,
    group_names: List = None,
    operation_type: str = None,
    user_ids: List = None,
    dry_run: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Adds or removes permission settings for the specified snapshot. You may add or remove specified Amazon Web Services account IDs from a snapshot's list of create volume permissions, but you cannot do both in a single operation. If you need to both add and remove account IDs for a snapshot, you must use multiple operations. You can make up to 500 modifications to a snapshot in a single operation. Encrypted snapshots and snapshots with Amazon Web Services Marketplace product codes cannot be made public. Snapshots encrypted with your default KMS key cannot be shared with other accounts. For more information about modifying snapshot permissions, see Share a snapshot in the Amazon Elastic Compute Cloud User Guide.

    Args:
        attribute(str, optional): The snapshot attribute to modify. Only volume creation permissions can be modified. Defaults to None.
        create_volume_permission(Dict, optional): A JSON representation of the snapshot attribute modification. Defaults to None.
        group_names(List, optional): The group to modify for the snapshot. Defaults to None.
        operation_type(str, optional): The type of operation to perform to the attribute. Defaults to None.
        snapshot_id(str): The ID of the snapshot.
        user_ids(List, optional): The account ID to modify for the snapshot. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.snapshot.attribute.modify(ctx, snapshot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.snapshot.attribute.modify snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_snapshot_attribute",
        op_kwargs={
            "Attribute": attribute,
            "CreateVolumePermission": create_volume_permission,
            "GroupNames": group_names,
            "OperationType": operation_type,
            "SnapshotId": snapshot_id,
            "UserIds": user_ids,
            "DryRun": dry_run,
        },
    )


async def reset(
    hub, ctx, attribute: str, snapshot_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Resets permission settings for the specified snapshot. For more information about modifying snapshot permissions, see Share a snapshot in the Amazon Elastic Compute Cloud User Guide.

    Args:
        attribute(str): The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.
        snapshot_id(str): The ID of the snapshot.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.snapshot.attribute.reset(
                ctx, attribute=value, snapshot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.snapshot.attribute.reset attribute=value, snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_snapshot_attribute",
        op_kwargs={
            "Attribute": attribute,
            "SnapshotId": snapshot_id,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a token for federation.  This API doesn't support root users. If you try to invoke GetFederationToken with root credentials, an error message similar to the following one appears:   Provided identity: Principal: .... User: .... cannot be used for federation with Amazon Connect

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.federation_token.get(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.federation_token.get instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="get_federation_token",
        op_kwargs={"InstanceId": instance_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, resource_group_name: str, component_name: str, tier: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the recommended monitoring configuration of the component.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.
        tier(str): The tier of the application component. Supported tiers include DOT_NET_CORE, DOT_NET_WORKER, DOT_NET_WEB, SQL_SERVER, and DEFAULT.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.configuration.recommendation.describe(
                ctx, resource_group_name=value, component_name=value, tier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.configuration.recommendation.describe resource_group_name=value, component_name=value, tier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_component_configuration_recommendation",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
            "Tier": tier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def delete_multiple(hub, ctx, account_id: str, vault_name: str) -> None:
    r"""
    **Autogenerated function**

    This operation deletes the notification configuration set for a vault. The operation is eventually consistent; that is, it might take some time for Amazon S3 Glacier to completely disable the notifications and you might still receive some notifications for a short time after you send the delete request. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For conceptual information and underlying REST API, see Configuring Vault Notifications in Amazon S3 Glacier and Delete Vault Notification Configuration  in the Amazon S3 Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.notification.delete_multiple(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.notification.delete_multiple account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="delete_vault_notifications",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )


async def get_all(hub, ctx, account_id: str, vault_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation retrieves the notification-configuration subresource of the specified vault. For information about setting a notification configuration on a vault, see SetVaultNotifications. If a notification configuration for a vault is not set, the operation returns a 404 Not Found error. For more information about vault notifications, see Configuring Vault Notifications in Amazon S3 Glacier.  An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM). For conceptual information and underlying REST API, see Configuring Vault Notifications in Amazon S3 Glacier and Get Vault Notification Configuration  in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.notification.get_all(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.notification.get_all account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="get_vault_notifications",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )


async def set_(
    hub, ctx, account_id: str, vault_name: str, vault_notification_config: Dict = None
) -> None:
    r"""
    **Autogenerated function**

    This operation configures notifications that will be sent when specific events happen to a vault. By default, you don't get any notifications. To configure vault notifications, send a PUT request to the notification-configuration subresource of the vault. The request should include a JSON document that provides an Amazon SNS topic and specific events for which you want Amazon S3 Glacier to send notifications to the topic. Amazon SNS topics must grant permission to the vault to be allowed to publish notifications to the topic. You can configure a vault to publish a notification for the following vault events:    ArchiveRetrievalCompleted This event occurs when a job that was initiated for an archive retrieval is completed (InitiateJob). The status of the completed job can be "Succeeded" or "Failed". The notification sent to the SNS topic is the same output as returned from DescribeJob.     InventoryRetrievalCompleted This event occurs when a job that was initiated for an inventory retrieval is completed (InitiateJob). The status of the completed job can be "Succeeded" or "Failed". The notification sent to the SNS topic is the same output as returned from DescribeJob.    An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM). For conceptual information and underlying REST API, see Configuring Vault Notifications in Amazon S3 Glacier and Set Vault Notification Configuration  in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        vault_notification_config(Dict, optional): Provides options for specifying notification configuration. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.notification.set(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.notification.set account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="set_vault_notifications",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "vaultNotificationConfig": vault_notification_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    transit_gateway_attachment_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the route tables to which the specified resource attachment propagates routes.

    Args:
        transit_gateway_attachment_id(str): The ID of the attachment.
        filters(List, optional): One or more filters. The possible values are:    transit-gateway-route-table-id - The ID of the transit gateway route table.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.attachment.propagation.get_all(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.attachment.propagation.get_all transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_transit_gateway_attachment_propagations",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    incident_template: Dict,
    name: str,
    actions: List = None,
    chat_channel: Dict = None,
    client_token: str = None,
    display_name: str = None,
    engagements: List = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a response plan that automates the initial response to incidents. A response plan engages contacts, starts chat channel collaboration, and initiates runbooks at the beginning of an incident.

    Args:
        actions(List, optional): The actions that the response plan starts at the beginning of an incident. Defaults to None.
        chat_channel(Dict, optional): The AWS Chatbot chat channel used for collaboration during an incident. Defaults to None.
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.
        display_name(str, optional): The long format of the response plan name. This field can contain spaces. Defaults to None.
        engagements(List, optional): The contacts and escalation plans that the response plan engages during an incident. Defaults to None.
        incident_template(Dict): Details used to create an incident when using this response plan.
        name(str): The short format name of the response plan. Can't include spaces.
        tags(Dict, optional): A list of tags that you are adding to the response plan. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.response_plan.create(
                ctx, incident_template=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.response_plan.create incident_template=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="create_response_plan",
        op_kwargs={
            "actions": actions,
            "chatChannel": chat_channel,
            "clientToken": client_token,
            "displayName": display_name,
            "engagements": engagements,
            "incidentTemplate": incident_template,
            "name": name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified response plan. Deleting a response plan stops all linked CloudWatch alarms and EventBridge events from creating an incident with this response plan.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the response plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.response_plan.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.response_plan.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="delete_response_plan",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of the specified response plan.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the response plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.response_plan.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.response_plan.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="get_response_plan",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all response plans in your account.

    Args:
        max_results(int, optional): The maximum number of response plans per page. Defaults to None.
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.response_plan.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.response_plan.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="list_response_plans",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    arn: str,
    actions: List = None,
    chat_channel: Dict = None,
    client_token: str = None,
    display_name: str = None,
    engagements: List = None,
    incident_template_dedupe_string: str = None,
    incident_template_impact: int = None,
    incident_template_notification_targets: List = None,
    incident_template_summary: str = None,
    incident_template_title: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified response plan.

    Args:
        actions(List, optional): The actions that this response plan takes at the beginning of an incident. Defaults to None.
        arn(str): The Amazon Resource Name (ARN) of the response plan.
        chat_channel(Dict, optional): The AWS Chatbot chat channel used for collaboration during an incident. Defaults to None.
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.
        display_name(str, optional): The long format name of the response plan. Can't contain spaces. Defaults to None.
        engagements(List, optional): The contacts and escalation plans that Incident Manager engages at the start of the incident. Defaults to None.
        incident_template_dedupe_string(str, optional): Used to create only one incident record for an incident. Defaults to None.
        incident_template_impact(int, optional): Defines the impact to the customers. Providing an impact overwrites the impact provided by a response plan.  Possible impacts:     5 - Severe impact    4 - High impact    3 - Medium impact    2 - Low impact    1 - No impact  . Defaults to None.
        incident_template_notification_targets(List, optional): The SNS targets that AWS Chatbot uses to notify the chat channels and perform actions on the incident record. Defaults to None.
        incident_template_summary(str, optional): A brief summary of the incident. This typically contains what has happened, what's currently happening, and next steps. Defaults to None.
        incident_template_title(str, optional): The short format name of the incident. Can't contain spaces. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.response_plan.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.response_plan.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="update_response_plan",
        op_kwargs={
            "actions": actions,
            "arn": arn,
            "chatChannel": chat_channel,
            "clientToken": client_token,
            "displayName": display_name,
            "engagements": engagements,
            "incidentTemplateDedupeString": incident_template_dedupe_string,
            "incidentTemplateImpact": incident_template_impact,
            "incidentTemplateNotificationTargets": incident_template_notification_targets,
            "incidentTemplateSummary": incident_template_summary,
            "incidentTemplateTitle": incident_template_title,
        },
    )
